@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018 Greenbone Networks GmbH
+# Copyright (C) 2018-2021 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -19,6 +19,11 @@
 import getpass
 import os
 import sys
+import uuid
+import string
+
+from random import choice, randrange
+from lxml import etree
 
 from gvm.errors import GvmError
 from gvm.xml import pretty_print
@@ -86,6 +91,78 @@ class Table:
         return "\n".join(row_strings)
 
 
+def yes_or_no(question):
+    """Asks the user to proceed or not in a gvmtools script
+
+    Arguments:
+        question (str): The condition the user should answer
+    """
+    reply = str(input(question + ' (y/n): ')).lower().strip()
+    if reply[0] == ('y'):
+        return True
+    if reply[0] == ('n'):
+        return False
+    else:
+        return yes_or_no("Please enter 'y' or 'n'")
+
+
+def error_and_exit(msg):
+    """Prints an error message and quits the gvmtools script
+
+    Arguments:
+        msg (str): The error message, that will be printed
+    """
+    print("\nError: {}\n".format(msg), file=sys.stderr)
+    sys.exit(1)
+
+
+def generate_random_ips(count: int):
+    """Generate count random IPv4s"""
+    exclude_127 = [i for i in range(1, 256)]
+    exclude_127.remove(127)
+    return [
+        '{}.{}.{}.{}'.format(
+            choice(exclude_127),
+            randrange(0, 256),
+            randrange(0, 256),
+            randrange(1, 255),
+        )
+        for i in range(count)
+    ]
+
+
+def generate_id(
+    size: int = 12, chars: str = string.ascii_uppercase + string.digits
+):
+    """Generate a random ID"""
+    return ''.join(choice(chars) for _ in range(size))
+
+
+def generate_uuid():
+    """Generate a random new uuid"""
+    return str(uuid.uuid4())
+
+
+def create_xml_tree(xml_doc):
+    """Creates an XML tree that can be read by an gvmtools script
+
+    Arguments:
+        xml_doc (str): Path to the xml document
+    """
+    try:
+        xml_tree = etree.parse(xml_doc)
+        xml_tree = xml_tree.getroot()
+    except IOError as err:
+        error_and_exit("Failed to read xml_file: {} (exit)".format(str(err)))
+    except etree.Error as err:
+        error_and_exit("Failed to parse xml_file: {} (exit)".format(str(err)))
+
+    if len(xml_tree) == 0:
+        error_and_exit("XML file is empty (exit)")
+
+    return xml_tree
+
+
 def do_not_run_as_root():
     if hasattr(os, 'geteuid') and os.geteuid() == 0:
         raise RuntimeError('This tool MUST NOT be run as root user.')
@@ -115,7 +192,7 @@ def authenticate(gmp, username=None, password=None):
 
     # Ask for login credentials if none are given.
     if not username:
-        while len(username) == 0:
+        while username is None or len(username) == 0:
             username = input('Enter username: ')
 
     if not password:
