@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2019 Greenbone Networks GmbH
+# Copyright (C) 2017-2021 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -38,7 +38,7 @@ __version__ = "2.0.0"
 logger = logging.getLogger(__name__)
 
 HELP_TEXT = """
-    Check-GMP Nagios Command Plugin {version} (C) 2017-2019 Greenbone Networks GmbH
+    Check-GMP Nagios Command Plugin {version} (C) 2017-2021 Greenbone Networks GmbH
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -131,15 +131,13 @@ class InstanceManager:
 
         except PermissionError:
             parser.error(
-                "The selected temporary database file {} or the parent dir has not the correct permissions.".format(
-                    self.db
-                )
+                "The selected temporary database file {} or the parent dir has"
+                " not the correct permissions.".format(self.db)
             )
 
     @staticmethod
     def _to_sql_bool(pending):
-        """ Replace True/False with 1/0.
-        """
+        """Replace True/False with 1/0."""
         return '1' if pending else '0'
 
     def connect_db(self):
@@ -156,8 +154,7 @@ class InstanceManager:
             logger.debug(e)
 
     def close_db(self):
-        """Close database
-        """
+        """Close database"""
         self.con_db.close()
 
     def set_host(self, host):
@@ -259,8 +256,7 @@ class InstanceManager:
         self.con_db.commit()
 
     def delete_report(self):
-        """Delete report from database
-        """
+        """Delete report from database"""
         self.cursor.execute("DELETE FROM Report WHERE host=?", (self.host,))
 
         # Save the changes
@@ -276,7 +272,7 @@ class InstanceManager:
         self.cursor.execute("DELETE FROM Report WHERE host=?", (ip,))
         self.con_db.isolation_level = None
         self.cursor.execute("VACUUM")
-        self.con_db.isolation_level = ''  # see: https://github.com/CxAalto/gtfspy/commit/8d05c3c94a6d4ca3ed675d88af93def7d5053bfe
+        self.con_db.isolation_level = ''  # see: https://github.com/CxAalto/gtfspy/commit/8d05c3c94a6d4ca3ed675d88af93def7d5053bfe # pylint: disable=line-too-long
         # Save the changes
         self.con_db.commit()
 
@@ -655,10 +651,10 @@ def status(gmp, im, script_args):
 
                 full_report = gmp.get_report(
                     report_id=last_report_id,
-                    filter="""sort-reverse=id result_hosts_only=1 
-                    min_cvss_base= min_qod= levels=hmlgd autofp={} 
-                    notes=0 apply_overrides={} overrides={} first=1 rows=-1 
-                    delta_states=cgns host={}""".format(
+                    filter="sort-reverse=id result_hosts_only=1 "
+                    "min_cvss_base= min_qod= levels=hmlgd autofp={} "
+                    "notes=0 apply_overrides={} overrides={} first=1 rows=-1 "
+                    "delta_states=cgns host={}".format(
                         script_args.autofp,
                         int(script_args.overrides),
                         int(script_args.apply_overrides),
@@ -1035,9 +1031,7 @@ ZERO = timedelta(0)
 
 
 class Utc(tzinfo):
-    """UTC Timezone
-
-    """
+    """UTC Timezone"""
 
     def utcoffset(self, dt):
         return ZERO
@@ -1056,9 +1050,7 @@ UTC = Utc()
 
 
 class FixedOffset(tzinfo):
-    """Fixed offset in hours and minutes from UTC
-
-    """
+    """Fixed offset in hours and minutes from UTC"""
 
     def __init__(self, offset_hours, offset_minutes, name):
         self.__offset_hours = offset_hours  # Keep for later __getinitargs__
@@ -1117,9 +1109,7 @@ def to_int(
 
 
 def parse_timezone(matches, default_timezone=UTC):
-    """Parses ISO 8601 time zone specs into tzinfo offsets
-
-    """
+    """Parses ISO 8601 time zone specs into tzinfo offsets"""
 
     if matches["timezone"] == "Z":
         return UTC
@@ -1133,8 +1123,8 @@ def parse_timezone(matches, default_timezone=UTC):
     minutes = to_int(matches, "tz_minute", default_to_zero=True)
     description = "%s%02d:%02d" % (sign, hours, minutes)
     if sign == "-":
-        hours = -hours
-        minutes = -minutes
+        hours = -1 * hours
+        minutes = -1 * minutes
     return FixedOffset(hours, minutes, description)
 
 
@@ -1194,7 +1184,7 @@ def parse_date(datestring, default_timezone=UTC):
             tzinfo=tz,
         )
     except Exception as e:
-        raise ParseError(e)
+        raise ParseError(e) from None
 
 
 def main(gmp, args):
